@@ -266,7 +266,7 @@ help.msg <- paste( " ", "Runs declustering", "",
 "X based on a given threshold and the number of subsequent obs that",
 "fall below the threshold.  That is, once an observation exceeds a", 
 "threshold (say u) a cluster begins.  After r observations fall below",
-"u\, that cluster terminates and a new one begins.  The",
+"u, that cluster terminates and a new one begins.  The",
 "maximum of each of these clusters is then returned to the data object",
 "with a new data column terminating with a .u[u]r[r]dc extension.  The rest of",
 "the new column is filled with the lesser of the minimum of the original data",
